﻿using DingTalk.Api;
using DingTalk.Api.Request;
using DingTalk.Api.Response;
using Kivii.HumanResources.DingTalk.Entities;
using Kivii.HumanResources.Entities;
using Kivii.Linq;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace Kivii.HumanResources.DingTalk
{
    public static class DingTalkExtension
    {
        #region 内部调用方法
        private static Dictionary<DateTime, string> _accessToken { get; set; }

        /// <summary>
        /// 更新AccessToken
        /// </summary>
        /// <param name="appKey"></param>
        /// <param name="appSecret"></param>
        private static void ModifyAccessToken(string appKey, string appSecret)
        {
            try
            {
                appKey.ThrowIfNullOrEmpty("appKey不能为空");
                appSecret.ThrowIfNullOrEmpty("appSecret不能为空");
                DefaultDingTalkClient client = new DefaultDingTalkClient("https://oapi.dingtalk.com/gettoken");
                var requestGettoken = new OapiGettokenRequest();
                requestGettoken.Appkey = appKey;//"dingwcrhckqsxjqc449k";
                requestGettoken.Appsecret = appSecret;//"GnnYS7_dH1M-JN5G-yFjfXmGSfdpdmXG8DeGps2XdLrRy-FvlRzmiv6EgBeyfdN1";
                requestGettoken.SetHttpMethod("GET");
                OapiGettokenResponse response = client.Execute(requestGettoken);
                _accessToken = new Dictionary<DateTime, string>();
                _accessToken.Add(DateTime.Now, response.AccessToken);
            }
            catch (Exception ex)
            {
                throw ex;
            }
        }

        /// <summary>
        /// 获取部门列表
        /// </summary>
        /// <param name="accessToken">调用企业接口凭证。</param>
        /// <param name="deptId">父部门ID。如果不传，默认部门为根部门，根部门ID为1。只支持查询下一级子部门，不支持查询多级子部门。</param>
        /// <param name="language">通讯录语言： zh_CN（默认）：中文 en_US：英文</param>
        /// <returns></returns>
        private static List<OapiV2DepartmentListsubResponse.DeptBaseResponseDomain> GetDept(string accessToken, long deptId = 1, string language = "zh_CN")
        {
            try
            {
                accessToken.ThrowIfNullOrEmpty("请传入AccessToken");
                var client = new DefaultDingTalkClient("https://oapi.dingtalk.com/topapi/v2/department/listsub");
                OapiV2DepartmentListsubRequest request = new OapiV2DepartmentListsubRequest();
                request.DeptId = deptId;
                request.Language = language;
                request.SetHttpMethod("POST");
                var rtns = client.Execute(request, accessToken);
                if (rtns.Errcode != 0) throw new Exception(rtns.Errmsg);
                if (rtns.Result.IsNullOrEmpty()) return new List<OapiV2DepartmentListsubResponse.DeptBaseResponseDomain>();

                return rtns.Result;
            }
            catch (Exception ex)
            {
                throw ex;
            }
        }

        /// <summary>
        /// 获取部门用户
        /// </summary>
        /// <param name="accessToken">调用企业接口凭证</param>
        /// <param name="deptId">部门ID，根部门ID为1</param>
        /// <param name="cursor">分页查询的游标，最开始传0，后续传返回参数中的next_cursor值。</param>
        /// <param name="size">分页长度。</param>
        /// <param name="orderField">部门成员的排序规则，默认不传是按自定义排序（custom）： entry_asc：代表按照进入部门的时间升序 entry_desc：代表按照进入部门的时间降序 modify_asc：代表按照部门信息修改时间升序 modify_desc：代表按照部门信息修改时间降序 custom：代表用户定义(未定义时按照拼音)排序</param>
        /// <param name="containAccessLimit">是否返回访问受限的员工</param>
        /// <param name="language">通讯录语言，默认为zh_CN。如果是英文，请传入en_US。</param>
        /// <returns></returns>
        private static List<OapiUserListsimpleResponse.ListUserSimpleResponseDomain> GetDeptUser(string accessToken, long deptId = 1, long cursor = 0, int size = 20, string orderField = "custom", bool containAccessLimit = false, string language = "zh_CN")
        {
            try
            {
                accessToken.ThrowIfNullOrEmpty("请传入AccessToken");
                var client = new DefaultDingTalkClient("https://oapi.dingtalk.com/topapi/user/listsimple");
                OapiUserListsimpleRequest request = new OapiUserListsimpleRequest();
                request.DeptId = deptId;
                request.Cursor = cursor;
                request.Size = size;
                request.OrderField = orderField;
                request.ContainAccessLimit = containAccessLimit;
                request.Language = language;
                var rtns = client.Execute(request, accessToken);
                if (rtns.Errcode != 0) throw new Exception(rtns.Errmsg);
                if (rtns.Result == null) rtns.Result = new OapiUserListsimpleResponse.PageResultDomain();
                if (rtns.Result.List.IsNullOrEmpty()) return new List<OapiUserListsimpleResponse.ListUserSimpleResponseDomain>();
                if (rtns.Result.HasMore)
                {
                    var more = GetDeptUser(accessToken, deptId, rtns.Result.NextCursor, size, orderField, containAccessLimit, language);
                    rtns.Result.List.AddRange(more);
                    return rtns.Result.List;
                }
                return rtns.Result.List;
            }
            catch (Exception ex)
            {
                throw ex;
            }
        }

        /// <summary>
        /// 获取钉钉考勤列表
        /// 起始与结束工作日最多相隔7天。
        /// </summary>
        /// <param name="accessToken"></param>
        /// <param name="workDateFrom">查询考勤打卡记录的起始工作日。格式为“yyyy-MM-dd HH:mm:ss”，HH:mm:ss可以使用00:00:00，将返回此日期从0点到24点的结果。</param>
        /// <param name="workDateTo">查询考勤打卡记录的结束工作日。格式为“yyyy-MM-dd HH:mm:ss”，HH:mm:ss可以使用00:00:00，将返回此日期从0点到24点的结果。</param>
        /// <param name="userIdList">员工在企业内的UserID列表，最多不能超过50个。</param>
        /// <param name="offset">表示获取考勤数据的起始点。第一次传0，如果还有多余数据，下次获取传的offset值为之前的offset+limit，012依次递增。</param>
        /// <param name="limit">表示获取考勤数据的条数，最大不能超过50条。</param>
        /// <param name="isL18n">是否为海外企业使用：true：海外平台使用 false（默认）：国内平台使用</param>
        /// <returns></returns>
        private static List<OapiAttendanceListResponse.RecordresultDomain> GetAttendanceList(string accessToken, string workDateFrom, string workDateTo, List<string> userIdList, int offset, int limit, bool isL18n = false)
        {
            try
            {
                accessToken.ThrowIfNullOrEmpty("请传入AccessToken");
                userIdList.ThrowIfNullOrEmpty("请传入要查询的用户列表");
                var client = new DefaultDingTalkClient("https://oapi.dingtalk.com/attendance/list");
                var requestAttendanceList = new OapiAttendanceListRequest();
                requestAttendanceList.WorkDateFrom = workDateFrom;
                requestAttendanceList.WorkDateTo = workDateTo;
                requestAttendanceList.UserIdList = userIdList;
                requestAttendanceList.Offset = offset;
                requestAttendanceList.Limit = limit;
                requestAttendanceList.IsI18n = isL18n;
                var rtns = client.Execute(requestAttendanceList, accessToken);
                if (rtns.Errcode != 0) throw new Exception(rtns.Errmsg);
                if (rtns.Recordresult.IsNullOrEmpty()) return new List<OapiAttendanceListResponse.RecordresultDomain>();
                if (rtns.HasMore)
                {
                    var more = GetAttendanceList(accessToken, workDateFrom, workDateTo, userIdList, offset + limit, limit, isL18n);
                    rtns.Recordresult.AddRange(more);
                    return rtns.Recordresult;
                }
                return rtns.Recordresult;
            }
            catch (Exception ex)
            {
                throw ex;
            }
        }

        /// <summary>
        /// 获取考勤组员工的userid
        /// </summary>
        /// <param name="accessToken"></param>
        /// <param name="opUserId">操作人userid</param>
        /// <param name="groupId">考勤组Id</param>
        /// <param name="cursor">游标值，表示从第几个开始，不传默认从第一个开始。</param>
        /// <returns></returns>
        private static OapiAttendanceGroupMemberusersListResponse.PageResultDomain GetDingTalkGroupMemberUsers(string accessToken, string opUserId, long groupId, int cursor = 0)
        {
            accessToken.ThrowIfNullOrEmpty("请传入AccessToken");
            opUserId.ThrowIfNullOrEmpty("请传入操作人userid");
            var client = new DefaultDingTalkClient("https://oapi.dingtalk.com/topapi/attendance/group/memberusers/list");
            OapiAttendanceGroupMemberusersListRequest req = new OapiAttendanceGroupMemberusersListRequest();
            req.Cursor = cursor;
            req.GroupId = groupId;
            req.OpUserId = opUserId;
            var rtns = client.Execute(req, accessToken);
            if (rtns.Errcode != 0) throw new Exception(rtns.Errmsg);
            if (rtns.Result == null) return new OapiAttendanceGroupMemberusersListResponse.PageResultDomain();
            if (rtns.Result.HasMore)
            {
                var more = GetDingTalkGroupMemberUsers(accessToken, opUserId, groupId, (int)rtns.Result.Cursor);
                rtns.Result.Result.AddRange(more.Result);
            }
            return rtns.Result;
        }

        #endregion

        #region 公共调用方法
        public static DateTime TimeStampToDateTime(string timeStamp)
        {
            try
            {
                if (timeStamp.Length != 13) throw new Exception("仅支持13位时间戳转化!");
                System.DateTime startTime = TimeZone.CurrentTimeZone.ToLocalTime(new System.DateTime(1970, 1, 1)); // 当地时区
                DateTime dt = startTime.AddMilliseconds(timeStamp.ToDouble());
                return dt;
            }
            catch (Exception ex)
            {
                throw new Exception($"TimeStampToDateTime:{timeStamp},{ex.Message}");
            }
        }

        public static List<List<string>> ListSplit(this List<string> list ,int size)
        {
            var rtns = new List<List<string>>();
            if (list.Count <= size) rtns.Add(list);
            else
            {
                for (int i = 0; i < list.Count; i += size)
                {
                    int take = list.Count - i <= size ? list.Count - i : size;
                    List<string> cList = new List<string>();
                    cList = list.Skip(i).Take(take).ToList();
                    rtns.Add(cList);
                }
            }
            return rtns;
        }

        /// <summary>
        /// 获取AccessToken
        /// </summary>
        /// <param name="thirdConfigInternalCode"></param>
        /// <returns></returns>
        public static string GetAccessToken(string thirdConfigInternalCode)
        {
            try
            {
                if (!_accessToken.IsNullOrEmpty())
                {
                    var currentAccessToken = _accessToken.First();
                    if (currentAccessToken.Key > DateTime.Now.AddHours(-2)) return currentAccessToken.Value;
                }

                thirdConfigInternalCode.ThrowIfNullOrEmpty("请传入thirdConfigInternalCode以获取新的AccessToken!");

                var conn = KiviiContext.GetOpenedDbConnection<ThirdConfig>();
                var config = conn.Single<ThirdConfig>(o => o.InternalCode == thirdConfigInternalCode);

                config.ThrowIfNull($"未找到内部编码为:{thirdConfigInternalCode} 对应的配置项!");
                var dingTalkConfig = config.GetConfig<DingTalkConfig>();

                ModifyAccessToken(dingTalkConfig.AppKey, dingTalkConfig.AppSecret);

                return _accessToken.First().Value;
            }
            catch (Exception ex)
            {
                throw ex;
            }
        }

        /// <summary>
        /// 获取部门列表
        /// </summary>
        /// <param name="accessToken">调用企业接口凭证。</param>
        /// <param name="deptId">父部门ID。如果不传，默认部门为根部门，根部门ID为1。只支持查询下一级子部门，不支持查询多级子部门。</param>
        /// <param name="language">通讯录语言： zh_CN（默认）：中文 en_US：英文</param>
        /// <returns></returns>
        public static List<DingTalkDept> GetDingTalkDept(string accessToken, long deptId = 1, string language = "zh_CN")
        {
            try
            {
                accessToken.ThrowIfNullOrEmpty("请传入AccessToken");
                var results = GetDept(accessToken, deptId, language);
                var rtns = new List<DingTalkDept>();
                foreach (var result in results)
                {
                    DingTalkDept dept = new DingTalkDept();
                    dept.PopulateInstance(result);
                    rtns.Add(dept);
                }
                return rtns;
            }
            catch (Exception ex)
            {
                throw ex;
            }
        }

        /// <summary>
        /// 获取部门用户
        /// </summary>
        /// <param name="accessToken">调用企业接口凭证</param>
        /// <param name="deptId">部门ID，根部门ID为1</param>
        /// <param name="cursor">分页查询的游标，最开始传0，后续传返回参数中的next_cursor值。</param>
        /// <param name="size">分页长度。</param>
        /// <param name="orderField">部门成员的排序规则，默认不传是按自定义排序（custom）： entry_asc：代表按照进入部门的时间升序 entry_desc：代表按照进入部门的时间降序 modify_asc：代表按照部门信息修改时间升序 modify_desc：代表按照部门信息修改时间降序 custom：代表用户定义(未定义时按照拼音)排序</param>
        /// <param name="containAccessLimit">是否返回访问受限的员工</param>
        /// <param name="language">通讯录语言，默认为zh_CN。如果是英文，请传入en_US。</param>
        /// <returns></returns>
        public static List<DingTalkDeptUser> GetDingTalkDeptUser(string accessToken, long deptId = 1, string deptName = "", long cursor = 0, int size = 20, string orderField = "custom", bool containAccessLimit = false, string language = "zh_CN")
        {
            try
            {
                accessToken.ThrowIfNullOrEmpty("请传入AccessToken");
                var results = GetDeptUser(accessToken, deptId, cursor, size, orderField, containAccessLimit, language);

                var rtns = new List<DingTalkDeptUser>();
                foreach (var result in results)
                {
                    DingTalkDeptUser user = new DingTalkDeptUser();
                    user.PopulateInstance(result);
                    user.DeptId = deptId;
                    user.DeptName = deptName;
                    rtns.Add(user);
                }

                return rtns;
            }
            catch (Exception ex)
            {
                throw ex;
            }
        }

        /// <summary>
        /// 获取钉钉考勤列表
        /// 起始与结束工作日最多相隔7天。
        /// </summary>
        /// <param name="accessToken"></param>
        /// <param name="BeginTime">查询考勤打卡记录的起始工作日。格式为“yyyy-MM-dd HH:mm:ss”，HH:mm:ss可以使用00:00:00，将返回此日期从0点到24点的结果。</param>
        /// <param name="EndTime">查询考勤打卡记录的结束工作日。格式为“yyyy-MM-dd HH:mm:ss”，HH:mm:ss可以使用00:00:00，将返回此日期从0点到24点的结果。</param>
        /// <param name="userIdList">员工在企业内的UserID列表，最多不能超过50个。</param>
        /// <param name="offset">表示获取考勤数据的起始点。第一次传0，如果还有多余数据，下次获取传的offset值为之前的offset+limit，012依次递增。</param>
        /// <param name="limit">表示获取考勤数据的条数，最大不能超过50条。</param>
        /// <param name="isL18n">是否为海外企业使用：true：海外平台使用 false（默认）：国内平台使用</param>
        /// <returns></returns>
        public static List<DingTalkAttendance> GetDingTalkAttendanceList(string accessToken, DateTime BeginTime, DateTime EndTime, List<string> userIdList, int offset = 0, int limit = 20, bool isL18n = false)
        {
            try
            {
                accessToken.ThrowIfNullOrEmpty("请传入AccessToken");
                userIdList.ThrowIfNullOrEmpty("请传入要查询的用户列表");
                if (BeginTime == DateTime.MinValue) BeginTime = DateTime.Now;
                if (EndTime == DateTime.MinValue) EndTime = DateTime.Now;
                var rtns = new List<DingTalkAttendance>();

                //日期跨度
                var intervalTime = EndTime - BeginTime;
                //小于等于7天的直接查
                if (intervalTime.Days <= 7)
                {
                    var beginTime = BeginTime.ToString("yyyy-MM-dd 00:00:00");
                    var endTime = EndTime.ToString("yyyy-MM-dd 00:00:00");

                    var results = GetAttendanceList(accessToken, beginTime, endTime, userIdList, offset, limit, isL18n);
                    foreach (var result in results)
                    {
                        DingTalkAttendance attendance = new DingTalkAttendance();
                        attendance.PopulateInstance(result);
                        rtns.Add(attendance);
                    }
                }
                else
                {
                    var count = (int)(intervalTime.Days / 7);
                    for (var i = 0; i < count; i++)
                    {
                        var beginTime = BeginTime.AddDays(i * 7).ToString("yyyy-MM-dd 00:00:00");
                        var endTime = BeginTime.AddDays(i * 7 + 6).ToString("yyyy-MM-dd 00:00:00");

                        var results = GetAttendanceList(accessToken, beginTime, endTime, userIdList, offset, limit, isL18n);
                        foreach (var result in results)
                        {
                            DingTalkAttendance attendance = new DingTalkAttendance();
                            attendance.PopulateInstance(result);
                            rtns.Add(attendance);
                        }
                    }
                    var beginTime2 = EndTime.AddDays(0 - (intervalTime.Days - 7 * count)).ToString("yyyy-MM-dd 00:00:00");
                    var endTime2 = EndTime.ToString("yyyy-MM-dd 00:00:00");

                    var results2 = GetAttendanceList(accessToken, beginTime2, endTime2, userIdList, offset, limit, isL18n);
                    foreach (var result in results2)
                    {
                        DingTalkAttendance attendance = new DingTalkAttendance();
                        attendance.PopulateInstance(result);
                        rtns.Add(attendance);
                    }
                }
                return rtns;
            }
            catch (Exception ex)
            {
                throw ex;
            }
        }

        /// <summary>
        /// 获取考勤组员工的userid
        /// </summary>
        /// <param name="accessToken"></param>
        /// <param name="opUserId">操作人userid</param>
        /// <param name="groupId">考勤组Id</param>
        /// <param name="cursor">游标值，表示从第几个开始，不传默认从第一个开始。</param>
        /// <returns></returns>
        public static List<string> GetGroupMemberUsers(string accessToken, string opUserId, long groupId, int cursor = 0)
        {
            try
            {
                accessToken.ThrowIfNullOrEmpty("请传入AccessToken");
                var results = GetDingTalkGroupMemberUsers(accessToken, opUserId, groupId, cursor);

                return results.Result;
            }
            catch (Exception ex)
            {
                throw ex;
            }
        }
        #endregion  
    }
}
