﻿using Kivii.HumanResources.DingTalk.Entities;
using Kivii.HumanResources.Entities;
using Kivii.Linq;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace Kivii.HumanResources.DingTalk
{
    public class AttendanceJob : IJob
    {
        public string Name => "钉钉考勤任务";

        public string Description => "钉钉考勤记录同步K5系统任务调度";

        public IJobContext TaskContext { get; set; }

        public void Dispose()
        {
        }

        public bool Execution()
        {
            return Sync();
        }
        private bool Sync()
        {
            var internalCode = TaskContext.Arguments.ContainsKey("InternalCode") ? TaskContext.Arguments["InternalCode"] : string.Empty;
            internalCode.ThrowIfNullOrEmpty("请传入InternalCode");
            var opUserId = TaskContext.Arguments.ContainsKey("OpUserId") ? TaskContext.Arguments["OpUserId"] : string.Empty;
            opUserId.ThrowIfNullOrEmpty("请传入OpUserId");
            var groupId = TaskContext.Arguments.ContainsKey("GroupId") ? long.Parse(TaskContext.Arguments["GroupId"]) : -1;
            (groupId == -1).ThrowIfTrue("请传入GroupId");
            var begin = TaskContext.Arguments.ContainsKey("BeginTime") ? TaskContext.Arguments["BeginTime"] : string.Empty;
            var end = TaskContext.Arguments.ContainsKey("EndTime") ? TaskContext.Arguments["EndTime"] : string.Empty;

            var beginTime = DateTime.Now;
            var endTime = DateTime.Now;

            DateTime.TryParse(begin, out beginTime);
            DateTime.TryParse(end, out endTime);

            var accessToken = DingTalkExtension.GetAccessToken(internalCode);

            try
            {
                var depts = DingTalkExtension.GetDingTalkDept(accessToken, 1, "zh_CN");

                var deptUsers = new List<DingTalkDeptUser>();
                foreach (var item in depts)
                {
                    var results = DingTalkExtension.GetDingTalkDeptUser(accessToken, item.DeptId, item.Name);
                    deptUsers.AddRange(results);
                }

                var userIds = DingTalkExtension.GetGroupMemberUsers(accessToken, opUserId, groupId);
                userIds.ThrowIfNullOrEmpty("当前考勤组未找到用户");

                List<DingTalkAttendance> attendances = new List<DingTalkAttendance>();
                var listUserIds = userIds.ListSplit(50);
                foreach (var item in listUserIds)
                {
                    attendances.AddRange(DingTalkExtension.GetDingTalkAttendanceList(accessToken, beginTime, endTime, item));
                }

                var conn = KiviiContext.GetOpenedDbConnection<Attendance>();

                var existAttendances = conn.Select<Attendance>(o => Sql.In(o.BizId, attendances.ConvertAll(p => p.Id.ToString())));
                int success = 0, skip = 0;
                foreach (var item in attendances)
                {
                    var deptUser = deptUsers.FirstOrDefault(o => o.Userid == item.UserId);
                    if (deptUser == null)
                    {
                        skip++;
                        continue;
                    }
                    item.UserName = deptUser.Name;
                    if (existAttendances.Exists(o => o.BizId == item.Id.ToString()))
                    {
                        skip++;
                        continue;
                    }
                    var attendance = new Attendance();
                    attendance.BizId = item.Id.ToString();
                    attendance.BizType = typeof(DingTalkAttendance).FullName;
                    attendance.UserName = deptUser.Name;
                    attendance.UserDepartment = deptUser.DeptName;
                    attendance.CheckType = item.CheckType;
                    attendance.SourceType = item.SourceType;
                    attendance.TimeResult = item.TimeResult;
                    attendance.LocationResult = item.LocationResult;
                    attendance.BaseCheckTime = DingTalkExtension.TimeStampToDateTime(item.BaseCheckTime);
                    if (attendance.TimeResult != "NotSigned")
                    {
                        attendance.UserCheckTime = DingTalkExtension.TimeStampToDateTime(item.UserCheckTime);
                        attendance.CheckTimeStamp = attendance.UserCheckTime.Value.ToUniversalTime().Ticks - attendance.BaseCheckTime.ToUniversalTime().Ticks;
                    }
                    else attendance.CheckTimeStamp = 0;
                    conn.Insert(attendance);
                    success++;
                }
                TaskContext.Message = $"New:{DateTime.Now:yyyy-MM-dd HH:mm:ss}成功查询{attendances.Count}条考勤记录,插入{success}条,跳过重复{skip}条!";
                return true;
            }
            catch (Exception ex)
            {
                TaskContext.Message = $"accessToken:{accessToken}";
                throw ex;
            }
        }
    }
}
